@@ -5,11 +5,6 @@
 #include <rng/RNG.h>
 #include <JRmath.h>
 
-using std::vector;
-using std::log;
-using std::exp;
-using std::fabs;
-
 
 // define parameters
 // mu  = par[0]
@@ -27,17 +22,16 @@ namespace RoBMA {
 DWN1::DWN1() : VectorDist("dwnorm_1s", 4) {}
 
 
-bool DWN1::checkParameterLength(vector<unsigned int> const &len) const
+bool DWN1::checkParameterLength(std::vector<unsigned int> const &len) const
 {
   // there is one less cut-point then weights
   return n_crit_x(len) == n_omega(len) - 1;
 }
 
-bool DWN1::checkParameterValue(vector<double const *> const &par,
-			    vector<unsigned int> const &len) const
+bool DWN1::checkParameterValue(std::vector<double const *> const &par,
+			    std::vector<unsigned int> const &len) const
 {
   bool omega_OK  = true;
-  bool var_OK;
 
   // all omegas are within [0, 1]
   for(unsigned j = 0; j < (n_omega(len)-1); ++j){
@@ -45,55 +39,52 @@ bool DWN1::checkParameterValue(vector<double const *> const &par,
   }
 
   // var is positive
-  var_OK = *par[1] > 0.0;
+  bool var_OK = *par[1] > 0.0;
 
   return omega_OK && var_OK;
 }
 
 double DWN1::logDensity(double const *x, unsigned int length, PDFType type,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper) const
 {
   double mu  = *par[0];
   double var = 1/ *par[1];
 
-  double w;
-  double nom;
   double denom = 0;
-  double denom_sum;
-  vector<double> denoms;
-  double log_lik;
+  double w = -68;
+  std::vector<double> denoms;
 
   // select weight to correspond to the current cut-off
   if(*x >= crit_x(par)[n_crit_x(len)-1]){
-    w = log(omega(par)[n_omega(len)-1]);
+    w = std::log(omega(par)[n_omega(len)-1]);
   }else if(*x < crit_x(par)[0]){
-    w = log(omega(par)[0]);
+    w = std::log(omega(par)[0]);
   }else{
     for(unsigned i = 1; i < n_omega(len); ++i){
       if( (*x < crit_x(par)[i] ) && (*x >= crit_x(par)[i-1]) ){
-        w = log(omega(par)[i]);
+        w = std::log(omega(par)[i]);
         break;
       }
     }
   }
 
   // compute the nominator
-  nom = dnorm(*x, mu, sqrt(var), true) + w;
+  double nom = dnorm(*x, mu, std::sqrt(var), true) + w;
 
   // compute the probabilities between cutpoints
   // the first one
-  denoms.push_back(pnorm(crit_x(par)[0], mu, sqrt(var), true, false));
+  denoms.push_back(pnorm(crit_x(par)[0], mu, std::sqrt(var), true, false));
   // check and correct for possibly negative numbers due to numerical imprecision
   if(denoms[0] < 0.0){
     denoms[0] = 0.0;
   }
-  denom_sum = denoms[0];
+  double denom_sum = denoms[0];
   // the ones in the middle
   if(n_omega(len) > 1){
     for(unsigned j = 1; j < n_omega(len) - 1; ++j){
-      denoms.push_back(pnorm(crit_x(par)[j], mu, sqrt(var), true, false) - denom_sum);
+      denoms.push_back(pnorm(crit_x(par)[j], mu, std::sqrt(var), true, false) - denom_sum);
       // check and correct for possibly negative numbers due to numerical imprecision
       if(denoms[j] < 0.0){
         denoms[j] = 0.0;
@@ -110,18 +101,18 @@ double DWN1::logDensity(double const *x, unsigned int length, PDFType type,
 
   // weight and sum the denominators
   for(unsigned k = 0; k < n_omega(len); ++k){
-    denom = denom + exp(log(denoms[k]) + log(omega(par)[k]));
+    denom = denom + std::exp(std::log(denoms[k]) + std::log(omega(par)[k]));
   }
 
   // compute the log likelihood
-  log_lik = nom-log(denom);
+  double log_lik = nom-std::log(denom);
 
   return log_lik;
 }
 
 void DWN1::randomSample(double *x, unsigned int length,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper,
 			  RNG *rng) const
 {
@@ -129,8 +120,8 @@ void DWN1::randomSample(double *x, unsigned int length,
 }
 
 void DWN1::support(double *lower, double *upper, unsigned int length,
-	     vector<double const *> const &par,
-	     vector<unsigned int> const &len) const
+	     std::vector<double const *> const &par,
+	     std::vector<unsigned int> const &len) const
 {
   // no idea whether this is correct
   for (unsigned int i = 0; i < length; ++i) {
@@ -139,7 +130,7 @@ void DWN1::support(double *lower, double *upper, unsigned int length,
   }
 }
 
-unsigned int DWN1::length(vector<unsigned int> const &len) const
+unsigned int DWN1::length(std::vector<unsigned int> const &len) const
 {
   // no idea how this works
   return 1;
@@ -147,15 +138,15 @@ unsigned int DWN1::length(vector<unsigned int> const &len) const
 
 
 void DWN1::typicalValue(double *x, unsigned int length,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper) const
 {
   // not implemented
 }
 
 
-bool DWN1::isSupportFixed(vector<bool> const &fixmask) const
+bool DWN1::isSupportFixed(std::vector<bool> const &fixmask) const
 {
   return true;
 }
